Enum ErrorCode
enum ErrorCode
A code identifying an error originating within this crate.
Variants
-
EofParsingArray -
EofParsingBool -
EofParsingComment -
EofParsingEscapeSequence -
EofParsingIdentifier -
EofParsingNull -
EofParsingNumber -
EofParsingObject -
EofParsingString -
EofParsingValue -
ExpectedBool -
ExpectedClosingBrace -
ExpectedClosingBracket -
ExpectedColon -
ExpectedComma -
ExpectedComment -
ExpectedIdentifier -
ExpectedNull -
ExpectedNumber -
ExpectedOpeningBrace -
ExpectedOpeningBracket -
ExpectedString -
ExpectedStringOrObject -
ExpectedValue -
InvalidBytes -
InvalidEscapeSequence -
InvalidKey -
LeadingZero -
LineTerminatorInString -
OverflowParsingNumber -
TrailingCharacters
Implementations
impl Clone for ErrorCode
fn clone(self: &Self) -> ErrorCode
impl Copy for ErrorCode
impl Debug for ErrorCode
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for ErrorCode
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for ErrorCode
impl PartialEq for ErrorCode
fn eq(self: &Self, other: &ErrorCode) -> bool
impl RefUnwindSafe for ErrorCode
impl Send for ErrorCode
impl StructuralPartialEq for ErrorCode
impl Sync for ErrorCode
impl Unpin for ErrorCode
impl UnsafeUnpin for ErrorCode
impl UnwindSafe for ErrorCode
impl<T> Any for ErrorCode
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ErrorCode
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ErrorCode
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ErrorCode
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ErrorCode
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for ErrorCode
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for ErrorCode
fn to_string(self: &Self) -> String
impl<T, U> Into for ErrorCode
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ErrorCode
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ErrorCode
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>