Struct Serializer
struct Serializer<W: Write> { ... }
A serializer that knows how to serialize types implementing Serialize as JSON5.
Implementations
impl<W: Write> Serializer<W>
fn new(w: W) -> Self
impl<T> Any for Serializer<W>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Serializer<W>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Serializer<W>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Serializer<W>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Serializer<W>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Serializer<W>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Serializer<W>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>